import React from 'react';
declare const enum onboardingState {
    done = "done",
    pending = "pending"
}
export interface InjectedOnboardingProps {
    onDone: () => Promise<void>;
}
interface State {
    onboarding?: onboardingState;
}
/**
 * A Higher Order Component that shows an Onboarding scene at the first app start (and again if onboarding was canceled)
 * The Onboarding Component will receive an {@code onDone} function, that receives no arguments and is to be called when
 * the onboarding scene should never be shown again
 *
 * @param App {React.ComponentType} the main app to show, once the onboarding is completed
 * @param Onboarding {React.ComponentType} the slideshow for onboarding
 * @param Loading {React.ComponentType} a loading screen to show while storage is read
 * @returns {React.ComponentClass}
 */
declare const withOnboarding: <P extends InjectedOnboardingProps>(App: React.ComponentType<{}>, Onboarding: React.ComponentType<P>, Loading: React.ComponentType<{}>) => {
    new (props: any): {
        onDone(): Promise<void>;
        componentDidMount(): Promise<void>;
        render(): JSX.Element;
        context: any;
        setState<K extends "onboarding">(state: State | ((prevState: Readonly<State>, props: Readonly<Pick<P, import("utility-types").SetDifference<keyof P, "onDone">>>) => State | Pick<State, K> | null) | Pick<State, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callBack?: (() => void) | undefined): void;
        readonly props: Readonly<{
            children?: React.ReactNode;
        }> & Readonly<Pick<P, import("utility-types").SetDifference<keyof P, "onDone">>>;
        state: Readonly<State>;
        refs: {
            [key: string]: React.ReactInstance;
        };
    };
    contextType?: React.Context<any> | undefined;
};
export default withOnboarding;
/**
 * Resets the onboarding status of the device. The next time the
 * user opens the app, the onboarding screen will be presented.
 *
 * @returns {Promise<void>} a promise the resolves upon
 * successful deletion of the key
 */
export declare function resetOnboarding(): Promise<void>;
