var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React from 'react';
import { AsyncStorage } from 'react-native';
const storageKey = '@onboarding-switch/onboarding-status';
/**
 * A Higher Order Component that shows an Onboarding scene at the first app start (and again if onboarding was canceled)
 * The Onboarding Component will receive an {@code onDone} function, that receives no arguments and is to be called when
 * the onboarding scene should never be shown again
 *
 * @param App {React.ComponentType} the main app to show, once the onboarding is completed
 * @param Onboarding {React.ComponentType} the slideshow for onboarding
 * @param Loading {React.ComponentType} a loading screen to show while storage is read
 * @returns {React.ComponentClass}
 */
const withOnboarding = (App, Onboarding, Loading) => class WithOnboarding extends React.Component {
    constructor(props) {
        super(props);
        this.state = {};
    }
    onDone() {
        return __awaiter(this, void 0, void 0, function* () {
            yield AsyncStorage.setItem(storageKey, "done" /* done */);
            this.setState({ onboarding: "done" /* done */ });
        });
    }
    componentDidMount() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const value = yield AsyncStorage.getItem(storageKey);
                if (!value) {
                    this.setState({ onboarding: "pending" /* pending */ });
                    yield AsyncStorage.setItem(storageKey, "pending" /* pending */);
                }
                else {
                    this.setState({ onboarding: value });
                }
            }
            catch (err) {
            }
        });
    }
    render() {
        switch (this.state.onboarding) {
            case "done" /* done */:
                return (<App {...this.props}/>);
            case "pending" /* pending */:
                // @ts-ignore
                return (<Onboarding onDone={this.onDone.bind(this)}/>);
            default:
                return (<Loading />);
        }
    }
};
export default withOnboarding;
/**
 * Resets the onboarding status of the device. The next time the
 * user opens the app, the onboarding screen will be presented.
 *
 * @returns {Promise<void>} a promise the resolves upon
 * successful deletion of the key
 */
export function resetOnboarding() {
    return __awaiter(this, void 0, void 0, function* () {
        yield AsyncStorage.removeItem(storageKey);
    });
}
